@@ -25,6 +25,7 @@ import sys
 import json
 import string as pystring
 from collections import defaultdict
+import logging
 
 from textblob.packages import nltk
 from textblob.decorators import cached_property, requires_nltk_corpus
@@ -45,7 +46,19 @@ from textblob.en import suggest
 # Wordnet interface
 # NOTE: textblob.wordnet is not imported so that the wordnet corpus can be lazy-loaded
 _wordnet = nltk.corpus.wordnet
+logger = logging.getLogger(__name__)
 
+def _penn_to_wordnet(tag):
+    '''Converts a Penn corpus tag into a Wordnet tag.'''
+    if tag in ("NN", "NNS", "NNP", "NNPS"):
+        return _wordnet.NOUN
+    if tag in ("JJ", "JJR", "JJS"):
+        return _wordnet.ADJ
+    if tag in ("VB", "VBD", "VBG", "VBN", "VBP", "VBZ"):
+        return _wordnet.VERB
+    if tag in ("RB", "RBR", "RBS"):
+        return _wordnet.ADV
+    return None
 
 class Word(unicode):
 
@@ -120,9 +133,24 @@ class Word(unicode):
     @cached_property
     @requires_nltk_corpus
     def lemma(self):
-        '''Return the lemma for a word using WordNet's morphy function.'''
+        '''Return the lemma of this word using Wordnet's morphy function.
+        '''
+        tag = _penn_to_wordnet(self.pos_tag) if (self.pos_tag is not None) else None
+        return self.lemmatize(pos=tag)
+
+    @requires_nltk_corpus
+    def lemmatize(self, pos=None):
+        '''Return the lemma for a word using WordNet's morphy function.
+
+        :param pos: Part of speech to filter upon. If `None`, defaults to
+            ``_wordnet.NOUN``.
+
+        .. versionadded:: 0.8.1
+        '''
+        if pos is None:
+            pos = _wordnet.NOUN
         lemmatizer = nltk.stem.WordNetLemmatizer()
-        return lemmatizer.lemmatize(self.string)
+        return lemmatizer.lemmatize(self.string, pos)
 
     @cached_property
     def synsets(self):
@@ -253,7 +281,7 @@ class WordList(list):
 
     def lemmatize(self):
         '''Return the lemma of each word in this WordList.'''
-        return self.__class__([word.lemma for word in self])
+        return self.__class__([word.lemmatize() for word in self])
 
 
 def _validated_param(obj, name, base_class, default, base_class_name=None):
